@@ -1,6 +1,6 @@
 package Reflex::POE::Wheel;
 BEGIN {
-  $Reflex::POE::Wheel::VERSION = '0.010';
+  $Reflex::POE::Wheel::VERSION = '0.011';
 }
 use Moose;
 extends 'Reflex::Object';
@@ -50,6 +50,11 @@ sub wheel_id {
 	return $self->wheel()->ID();
 }
 
+sub put {
+	my $self = shift;
+	$self->wheel()->put(@_);
+}
+
 sub DEMOLISH {
 	my $self = shift;
 	$self->demolish_wheel();
@@ -100,7 +105,7 @@ Reflex::POE::Wheel - Base class for POE::Wheel wrappers.
 
 =head1 VERSION
 
-version 0.010
+version 0.011
 
 =head1 SYNOPSIS
 
@@ -138,6 +143,12 @@ C<< $foo->wheel()->ID() >> can also be used instead.
 Cause the internal wheel to be demolished.  Provided as a method since
 some wheels may require special handling.
 
+=head3 put
+
+put() sends its parameters to the POE::Wheel's put() method.
+
+	$reflex_poe_wheel->put("one", "two");
+
 =head2 Required Subclass Methods
 
 These subclass methods are used to configure subclasses for their
